netapp_ontap.models.dcn_version API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.dcn_version`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class DcnVersionSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the DcnVersion object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `full: str GET`

    The full version string.

    Example: 9.18.1U0 Wed Jan 15 18:20:57 UTC 2026

  `generation: Size GET`

    The generation portion of the version.

    Example: 9

  `major: Size GET`

    The major portion of the version.

    Example: 4

  `minor: Size GET`

    The minor portion of the version.

    Example: 0

  `patch: str GET`

    The patch portion of the version.

    Example: U2